//  File:  Enum\Enum.java

/**
 * Demonstrate how to use Java enumerations
 * 
 * @author Bary W Pollack
 * @version Feb. 19, 2005
 */

enum Weekday { SUN, MON, TUES, WED, THURS, FRI, SAT };

enum Size {
    SMALL ("tiny"), MEDIUM ("middling"), LARGE ("giant");
    private final String sWord;
    Size(String sWord) { this.sWord = sWord; }
    String getWord() { return sWord; }
};

public class Enum {

    public static void main(String [] argv) {
        System.out.println("Demonstrate Java's enumerations\n");
        Weekday weekday = Weekday.WED;
        System.out.println("weekday value =   " + weekday);
        System.out.println("weekday ordinal = " + weekday.ordinal());
        System.out.println("weekday name =    " + weekday.name());
        System.out.print("Weekday values = ");
        for (Weekday wd : Weekday.values())
            System.out.print(" " + wd);
        System.out.println("\n");

        Size size = Size.MEDIUM;
        System.out.println("size value =      " + size);
        System.out.println("size ordinal =    " + size.ordinal());
        System.out.println("size.name =       " + size.name());
        System.out.print("Size values =    ");
        for (Size sz : Size.values())
            System.out.print(" " + sz + "(" + sz.getWord() + ")");
        System.out.println("\n");
    }
   
}

/*    Output from this program:

Demonstrate Java's enumerations

weekday value =   WED
weekday ordinal = 3
weekday name =    WED
Weekday values =  SUN MON TUES WED THURS FRI SAT

size value =      MEDIUM
size ordinal =    1
size.name =       MEDIUM
Size values =     SMALL(tiny) MEDIUM(middling) LARGE(giant)

*/
